@@ -14,53 +14,59 @@
 #   limitations under the License.
 #
 
+from hsml.connection import CONNECTION_SAAS_HOSTNAME
+
 from hsml.client.hopsworks import base as hw_base
 from hsml.client.hopsworks import internal as hw_internal
 from hsml.client.hopsworks import external as hw_external
 
-from hsml.client import istio
 from hsml.client.istio import base as ist_base
 from hsml.client.istio import internal as ist_internal
+from hsml.client.istio import external as ist_external
+
+
+_client_type = None
+_saas_connection = None
 
 _hopsworks_client = None
 _istio_client = None
 
+_kserve_installed = None
+_serving_resource_limits = None
+_serving_num_instances_limits = None
+
 
 def init(
     client_type,
     host=None,
     port=None,
     project=None,
-    region_name=None,
-    secrets_store=None,
     hostname_verification=None,
     trust_store_path=None,
     api_key_file=None,
     api_key_value=None,
 ):
+    global _client_type
+    _client_type = client_type
+
+    global _saas_connection
+    _saas_connection = host == CONNECTION_SAAS_HOSTNAME
+
     global _hopsworks_client
     if not _hopsworks_client:
         if client_type == "internal":
             _hopsworks_client = hw_internal.Client()
         elif client_type == "external":
-            _hopsworks_client = hw_external.external.Client(
+            _hopsworks_client = hw_external.Client(
                 host,
                 port,
                 project,
-                region_name,
-                secrets_store,
                 hostname_verification,
                 trust_store_path,
                 api_key_file,
                 api_key_value,
             )
 
-    global _istio_client
-    if not _istio_client and client_type == "internal" and istio.is_available():
-        _istio_client = (
-            ist_internal.Client()
-        )  # TODO: Add external Istio client after adding support for AKS, EKS
-
 
 def get_instance() -> hw_base.Client:
     global _hopsworks_client
@@ -69,11 +75,59 @@ def get_instance() -> hw_base.Client:
     raise Exception("Couldn't find client. Try reconnecting to Hopsworks.")
 
 
+def set_istio_client(host, port, project=None, api_key_value=None):
+    global _client_type, _istio_client
+
+    if not _istio_client:
+        if _client_type == "internal":
+            _istio_client = ist_internal.Client(host, port)
+        elif _client_type == "external":
+            _istio_client = ist_external.Client(host, port, project, api_key_value)
+
+
 def get_istio_instance() -> ist_base.Client:
     global _istio_client
-    if _istio_client:
-        return _istio_client
-    raise Exception("Couldn't find the istio client. Try reconnecting to Hopsworks.")
+    return _istio_client
+
+
+def get_client_type() -> str:
+    global _client_type
+    return _client_type
+
+
+def is_saas_connection() -> bool:
+    global _saas_connection
+    return _saas_connection
+
+
+def set_kserve_installed(kserve_installed):
+    global _kserve_installed
+    _kserve_installed = kserve_installed
+
+
+def is_kserve_installed() -> bool:
+    global _kserve_installed
+    return _kserve_installed
+
+
+def set_serving_resource_limits(max_resources):
+    global _serving_resource_limits
+    _serving_resource_limits = max_resources
+
+
+def get_serving_resource_limits():
+    global _serving_resource_limits
+    return _serving_resource_limits
+
+
+def set_serving_num_instances_limits(num_instances_range):
+    global _serving_num_instances_limits
+    _serving_num_instances_limits = num_instances_range
+
+
+def get_serving_num_instances_limits():
+    global _serving_num_instances_limits
+    return _serving_num_instances_limits
 
 
 def stop():
