@@ -15,18 +15,30 @@
 #
 
 
+DEFAULT = dict()  # used as default parameter for a class object
+
+
 class MODEL_SERVING:
     MODELS_DATASET = "Models"
 
 
+class ARTIFACT_VERSION:
+    CREATE = "CREATE"
+
+
 class RESOURCES:
-    NUM_INSTANCES = 1
-    CORES = 1
-    MEMORY = 1024
-    GPUS = 0
+    # default values, not hard limits
+    MIN_CORES = 0.2
+    MIN_MEMORY = 32
+    MIN_GPUS = 0
+    MAX_CORES = 1
+    MAX_MEMORY = 1024
+    MAX_GPUS = 0
 
 
-class KAFKA_TOPIC_CONFIG:
+class KAFKA_TOPIC:
+    NONE = "NONE"
+    CREATE = "CREATE"
     NUM_REPLICAS = 1
     NUM_PARTITIONS = 1
 
@@ -51,7 +63,7 @@ class PREDICTOR:
     MODEL_SERVER_PYTHON = "PYTHON"
     MODEL_SERVER_TF_SERVING = "TENSORFLOW_SERVING"
     SERVING_TOOL_DEFAULT = "DEFAULT"
-    SERVING_TOOL_KFSERVING = "KFSERVING"
+    SERVING_TOOL_KSERVE = "KSERVE"
 
 
 class PREDICTOR_STATE:
@@ -60,3 +72,18 @@ class PREDICTOR_STATE:
     STATUS_STOPPING = "STOPPING"
     STATUS_STOPPED = "STOPPED"
     STATUS_UPDATING = "UPDATING"
+
+
+class INFERENCE_ENDPOINTS:
+    ENDPOINT_TYPE_NODE = "NODE"
+    ENDPOINT_TYPE_KUBE_CLUSTER = "KUBE_CLUSTER"
+    ENDPOINT_TYPE_LOAD_BALANCER = "LOAD_BALANCER"
+    PORT_NAME_HTTP = "HTTP"
+    PORT_NAME_HTTPS = "HTTPS"
+    PORT_NAME_STATUS_PORT = "STATUS"
+    PORT_NAME_TLS = "TLS"
+
+
+class DEPLOYABLE_COMPONENT:
+    PREDICTOR = "predictor"
+    TRANSFORMER = "transformer"
